==> ice-3.7.5.tgz: package/src/es5/Ice/RemoteLogger.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.5
//
// <auto-generated>
//
// Generated from file `RemoteLogger.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Struct", "../Ice/Exception", "../Ice/EnumBase", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/BuiltinSequences"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * An enumeration representing the different types of log messages.
   *
   **/

  Ice.LogMessageType = Slice.defineEnum([['PrintMessage', 0], ['TraceMessage', 1], ['WarningMessage', 2], ['ErrorMessage', 3]]);
  Slice.defineSequence(Ice, "LogMessageTypeSeqHelper", "Ice.LogMessageType._helper", false);
  /**
   * A complete log message.
   *
   **/

  Ice.LogMessage = /*#__PURE__*/function () {
    function _class() {
      var type = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Ice.LogMessageType.PrintMessage;
      var timestamp = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Ice.Long(0, 0);
      var traceCategory = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "";
      var message = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : "";

      _classCallCheck(this, _class);

      this.type = type;
      this.timestamp = timestamp;
      this.traceCategory = traceCategory;
      this.message = message;
    }

    _createClass(_class, [{
      key: "_write",
      value: function _write(ostr) {
        Ice.LogMessageType._write(ostr, this.type);

        ostr.writeLong(this.timestamp);
        ostr.writeString(this.traceCategory);
        ostr.writeString(this.message);
      }
    }, {
      key: "_read",
      value: function _read(istr) {
        this.type = Ice.LogMessageType._read(istr);
        this.timestamp = istr.readLong();
        this.traceCategory = istr.readString();
        this.message = istr.readString();
      }
    }], [{
      key: "minWireSize",
      get: function get() {
        return 11;
      }
    }]);

    return _class;
  }();

  Slice.defineStruct(Ice.LogMessage, true, true);
  Slice.defineSequence(Ice, "LogMessageSeqHelper", "Ice.LogMessage", false);
  var iceC_Ice_RemoteLogger_ids = ["::Ice::Object", "::Ice::RemoteLogger"];
  /**
   * The Ice remote logger interface. An application can implement a
   * RemoteLogger to receive the log messages sent to the local {@link Logger}
   * of another Ice application.
   *
   **/

  Ice.RemoteLogger = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class2, _Ice$Object);

    var _super = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super.apply(this, arguments);
    }

    return _class2;
  }(Ice.Object);

  Ice.RemoteLoggerPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class3, _Ice$ObjectPrx);

    var _super2 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super2.apply(this, arguments);
    }

    return _class3;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.RemoteLogger, Ice.RemoteLoggerPrx, iceC_Ice_RemoteLogger_ids, 1, {
    "init": [,,,,, [[7], ["Ice.LogMessageSeqHelper"]],,,,],
    "log": [,,,,, [[Ice.LogMessage]],,,,]
  });
  /**
   * Thrown when the provided RemoteLogger was previously attached to a LoggerAdmin.
   *
   **/

  Ice.RemoteLoggerAlreadyAttachedException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class4, _Ice$UserException);

    var _super3 = _createSuper(_class4);

    function _class4() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class4);

      return _super3.call(this, _cause);
    }

    _createClass(_class4, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.RemoteLoggerAlreadyAttachedException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::RemoteLoggerAlreadyAttachedException";
      }
    }]);

    return _class4;
  }(Ice.UserException);

  var iceC_Ice_LoggerAdmin_ids = ["::Ice::LoggerAdmin", "::Ice::Object"];
  /**
   * The interface of the admin object that allows an Ice application the attach its
   * {@link RemoteLogger} to the {@link Logger} of this admin object's Ice communicator.
   *
   **/

  Ice.LoggerAdmin = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class5, _Ice$Object2);

    var _super4 = _createSuper(_class5);

    function _class5() {
      _classCallCheck(this, _class5);

      return _super4.apply(this, arguments);
    }

    return _class5;
  }(Ice.Object);

  Ice.LoggerAdminPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class6, _Ice$ObjectPrx2);

    var _super5 = _createSuper(_class6);

    function _class6() {
      _classCallCheck(this, _class6);

      return _super5.apply(this, arguments);
    }

    return _class6;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.LoggerAdmin, Ice.LoggerAdminPrx, iceC_Ice_LoggerAdmin_ids, 0, {
    "attachRemoteLogger": [,,,,, [["Ice.RemoteLoggerPrx"], ["Ice.LogMessageTypeSeqHelper"], ["Ice.StringSeqHelper"], [3]],, [Ice.RemoteLoggerAlreadyAttachedException],,],
    "detachRemoteLogger": [,,,, [1], [["Ice.RemoteLoggerPrx"]],,,,],
    "getLog": [,,,, ["Ice.LogMessageSeqHelper"], [["Ice.LogMessageTypeSeqHelper"], ["Ice.StringSeqHelper"], [3]], [[7]],,,]
  });
  /* slice2js browser-bundle-skip */

  exports.Ice = Ice;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */

==> ice-3.7.70.tgz: package/src/es5/Ice/RemoteLogger.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.7
//
// <auto-generated>
//
// Generated from file `RemoteLogger.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Struct", "../Ice/Exception", "../Ice/EnumBase", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/BuiltinSequences"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * An enumeration representing the different types of log messages.
   *
   **/

  Ice.LogMessageType = Slice.defineEnum([['PrintMessage', 0], ['TraceMessage', 1], ['WarningMessage', 2], ['ErrorMessage', 3]]);
  Slice.defineSequence(Ice, "LogMessageTypeSeqHelper", "Ice.LogMessageType._helper", false);
  /**
   * A complete log message.
   *
   **/

  Ice.LogMessage = /*#__PURE__*/function () {
    function _class() {
      var type = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : Ice.LogMessageType.PrintMessage;
      var timestamp = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Ice.Long(0, 0);
      var traceCategory = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "";
      var message = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : "";

      _classCallCheck(this, _class);

      this.type = type;
      this.timestamp = timestamp;
      this.traceCategory = traceCategory;
      this.message = message;
    }

    _createClass(_class, [{
      key: "_write",
      value: function _write(ostr) {
        Ice.LogMessageType._write(ostr, this.type);

        ostr.writeLong(this.timestamp);
        ostr.writeString(this.traceCategory);
        ostr.writeString(this.message);
      }
    }, {
      key: "_read",
      value: function _read(istr) {
        this.type = Ice.LogMessageType._read(istr);
        this.timestamp = istr.readLong();
        this.traceCategory = istr.readString();
        this.message = istr.readString();
      }
    }], [{
      key: "minWireSize",
      get: function get() {
        return 11;
      }
    }]);

    return _class;
  }();

  Slice.defineStruct(Ice.LogMessage, true, true);
  Slice.defineSequence(Ice, "LogMessageSeqHelper", "Ice.LogMessage", false);
  var iceC_Ice_RemoteLogger_ids = ["::Ice::Object", "::Ice::RemoteLogger"];
  /**
   * The Ice remote logger interface. An application can implement a
   * RemoteLogger to receive the log messages sent to the local {@link Logger}
   * of another Ice application.
   *
   **/

  Ice.RemoteLogger = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class2, _Ice$Object);

    var _super = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super.apply(this, arguments);
    }

    return _class2;
  }(Ice.Object);

  Ice.RemoteLoggerPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class3, _Ice$ObjectPrx);

    var _super2 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super2.apply(this, arguments);
    }

    return _class3;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.RemoteLogger, Ice.RemoteLoggerPrx, iceC_Ice_RemoteLogger_ids, 1, {
    "init": [,,,,, [[7], ["Ice.LogMessageSeqHelper"]],,,,],
    "log": [,,,,, [[Ice.LogMessage]],,,,]
  });
  /**
   * Thrown when the provided RemoteLogger was previously attached to a LoggerAdmin.
   *
   **/

  Ice.RemoteLoggerAlreadyAttachedException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class4, _Ice$UserException);

    var _super3 = _createSuper(_class4);

    function _class4() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class4);

      return _super3.call(this, _cause);
    }

    _createClass(_class4, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.RemoteLoggerAlreadyAttachedException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::RemoteLoggerAlreadyAttachedException";
      }
    }]);

    return _class4;
  }(Ice.UserException);

  var iceC_Ice_LoggerAdmin_ids = ["::Ice::LoggerAdmin", "::Ice::Object"];
  /**
   * The interface of the admin object that allows an Ice application the attach its
   * {@link RemoteLogger} to the {@link Logger} of this admin object's Ice communicator.
   *
   **/

  Ice.LoggerAdmin = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class5, _Ice$Object2);

    var _super4 = _createSuper(_class5);

    function _class5() {
      _classCallCheck(this, _class5);

      return _super4.apply(this, arguments);
    }

    return _class5;
  }(Ice.Object);

  Ice.LoggerAdminPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class6, _Ice$ObjectPrx2);

    var _super5 = _createSuper(_class6);

    function _class6() {
      _classCallCheck(this, _class6);

      return _super5.apply(this, arguments);
    }

    return _class6;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.LoggerAdmin, Ice.LoggerAdminPrx, iceC_Ice_LoggerAdmin_ids, 0, {
    "attachRemoteLogger": [,,,,, [["Ice.RemoteLoggerPrx"], ["Ice.LogMessageTypeSeqHelper"], ["Ice.StringSeqHelper"], [3]],, [Ice.RemoteLoggerAlreadyAttachedException],,],
    "detachRemoteLogger": [,,,, [1], [["Ice.RemoteLoggerPrx"]],,,,],
    "getLog": [,,,, ["Ice.LogMessageSeqHelper"], [["Ice.LogMessageTypeSeqHelper"], ["Ice.StringSeqHelper"], [3]], [[7]],,,]
  });
  /* slice2js browser-bundle-skip */

  exports.Ice = Ice;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */
